{ withSystem, self, inputs, ...}:
{
  flake = {
    nixosConfigurations = {
      dumpyourvms = self.nixos-flake.lib.mkLinuxSystem {
        nixpkgs.hostPlatform = "x86_64-linux";
        imports = [
          self.nixosModules.base
          ./dumpyourvms
          self.nixosModules.teutat3s
          self.nixosModules.audio
          self.nixosModules.bluetooth
          self.nixosModules.desktop-extended
          self.nixosModules.docker
          self.nixosModules.graphical
          self.nixosModules.nextcloud
          self.nixosModules.office
          self.nixosModules.printing
        ];
      };

      ryzensun = self.nixos-flake.lib.mkLinuxSystem {
        nixpkgs.hostPlatform = "x86_64-linux";
        imports = [
          self.nixosModules.base
          ./ryzensun
          self.nixosModules.teutat3s
          self.nixosModules.audio
          self.nixosModules.desktop-extended
          self.nixosModules.docker
          self.nixosModules.graphical
          self.nixosModules.office
          self.nixosModules.printing
          self.nixosModules.virtualisation
        ];
      };

      fae = self.nixos-flake.lib.mkLinuxSystem {
        nixpkgs.hostPlatform = "aarch64-linux";
        imports = [
          self.nixosModules.base
          inputs.nixos-hardware.nixosModules.raspberry-pi-4
          ./fae
          self.nixosModules.pub-solar
          self.nixosModules.acme
        ];
      };

      #powder = self.nixos-flake.lib.mkLinuxSystem {
      #  nixpkgs.hostPlatform = "aarch64-linux";
      #  imports = [
      #    self.nixosModules.base
      #    inputs.nixos-hardware.nixosModules.raspberry-pi-4
      #    ./powder
      #    self.nixosModules.teutat3s
      #    self.nixosModules.docker
      #    self.nixosModules.wireguard-client
      #    self.nixosModules.invoiceplane
      #  ];
      #};

      iso = self.nixos-flake.lib.mkLinuxSystem {
        nixpkgs.hostPlatform = "x86_64-linux";
        imports = [
          "${inputs.nixpkgs}/nixos/modules/installer/cd-dvd/installation-cd-minimal.nix"
          self.nixosModules.base
          ./iso
          self.nixosModules.nixos
        ];
      };

      iso-arm = self.nixos-flake.lib.mkLinuxSystem {
        nixpkgs.hostPlatform = "aarch64-linux";
        nixpkgs.buildPlatform = "x86_64-linux";
        imports = [
          "${inputs.nixpkgs}/nixos/modules/installer/cd-dvd/installation-cd-minimal.nix"
          self.nixosModules.base
          ./iso
          self.nixosModules.nixos
        ];
      };

      iso-graphical = self.nixos-flake.lib.mkLinuxSystem {
        nixpkgs.hostPlatform = "x86_64-linux";
        imports = [
          "${inputs.nixpkgs}/nixos/modules/installer/cd-dvd/installation-cd-minimal.nix"
          self.nixosModules.base
          ./iso
          self.nixosModules.nixos
          self.nixosModules.graphical
          self.nixosModules.audio
          self.nixosModules.bluetooth
          ({ ... }: { pub-solar.graphical.wayland.software-renderer.enable = true; })
        ];
      };
    };
  };
}
